@@ -13,6 +13,8 @@ import argparse
 from operator import itemgetter
 from PIL import Image
 from urllib.parse import urlparse
+
+from label_studio_tools.core.utils.params import get_env
 from nltk.tokenize import WhitespaceTokenizer
 from lxml import etree
 from collections import defaultdict
@@ -21,6 +23,7 @@ logger = logging.getLogger(__name__)
 
 _LABEL_TAGS = {'Label', 'Choice'}
 _NOT_CONTROL_TAGS = {'Filter',}
+LOCAL_FILES_DOCUMENT_ROOT = get_env('LOCAL_FILES_DOCUMENT_ROOT', default=os.path.abspath(os.sep))
 
 class ExpandFullPath(argparse.Action):
     def __call__(self, parser, namespace, values, option_string=None):
@@ -43,7 +46,7 @@ def create_tokens_and_tags(text, spans):
     #tokens_and_idx = tokenize(text) # This function doesn't work properly if text contains multiple whitespaces...
     token_index_tuples = [token for token in WhitespaceTokenizer().span_tokenize(text)]
     tokens_and_idx = [(text[start:end], start) for start, end in token_index_tuples]
-    if spans:
+    if spans and all([span.get('start') is not None and span.get('end') is not None for span in spans]):
         spans = list(sorted(spans, key=itemgetter('start')))
         span = spans.pop(0)
         span_start = span['start']
@@ -117,11 +120,9 @@ def download(url, output_dir, filename=None, project_dir=None, return_relative_p
     if is_local_file:
         filename, dir_path = url.split('/data/', 1)[-1].split('?d=')
         dir_path = str(urllib.parse.unquote(dir_path))
-        if not os.path.exists(dir_path):
-            raise FileNotFoundError(dir_path)
-        filepath = os.path.join(dir_path, filename)
-        if return_relative_path:
-            raise NotImplementedError()
+        filepath = os.path.join(LOCAL_FILES_DOCUMENT_ROOT, dir_path)
+        if not os.path.exists(filepath):
+            raise FileNotFoundError(filepath)
         return filepath
 
     if filename is None:
@@ -234,7 +235,7 @@ def parse_config(config_string):
         tag_info['inputs'] = []
         for input_tag_name in tag_info['to_name']:
             if input_tag_name not in inputs:
-                logger.warning(
+                logger.debug(
                     f'to_name={input_tag_name} is specified for output tag name={output_tag}, '
                     'but we can\'t find it among input tags')
                 continue
